Learn R Programming

useful (version 1.1.5)

fortify.kmeans: fortify.kmeans

Description

Fortify a kmeans model with its data

Usage

## S3 method for class 'kmeans':
fortify(model, data = NULL, ...)

Arguments

model
kmeans model
data
Data used to fit the model
...
Not Used

Value

  • The original data with extra columns:
  • .xThe projected x position.
  • .yThe projected y position.
  • .ClusterThe cluster that point belongs to.

Details

Prepares a kmeans object to be plotted using cmdscale to compute the projected x/y coordinates. If data is not provided, then just the center points are calculated.

See Also

kmeans fortify ggplot plot.kmeans

Examples

Run this code
k1 <- kmeans(x=iris[, 1:4], centers=3)
hold <- fortify(k1, data=iris)
head(hold)
hold2 <- fortify(k1)
head(hold2)

Run the code above in your browser using DataLab