A vector of the same length of x that
specifies the time component of each element of
x.
acf
Logical indicating if the acf and pacf should
be plotted.
lag.max
maximum lag at which to calculate the acf.
Default is 10*log10(N/m) where N is the number of
observations and m the number of series. Will be
automatically limited to one less than the number of
observations in the series.
na.action
function to be called to handle missing
values. na.pass can be used.
demean
logical. Should the covariances be about
the sample means?
xlab
X-axis label.
ylab
Y-axis label.
title
Graph title.
...
Further arguments.
Value
A ggplot object if acf is FALSE, otherwise
TRUE indicating success.
Details
Plot a ts object and, if desired, it's acf and pacf.