Learn R Programming

useful (version 1.2.7)

ts.plotter: ts.plotter

Description

Plot a ts object

Usage

ts.plotter(
  data,
  time = NULL,
  title = "Series Plot",
  xlab = "Time",
  ylab = "Rate"
)

Value

A ggplot object

Arguments

data

A ts object to be plotted.

time

A vector of the same length of data that specifies the time component of each element of data.

title

Title of plot.

xlab

X-axis label.

ylab

Y-axis label.

Author

Jared P. Lander

Details

Fortifies, then plots a ts object.

Examples

Run this code

ts.plotter(sunspot.year)

Run the code above in your browser using DataLab