Description
Plot a ts object
Usage
ts.plotter(
data,
time = NULL,
title = "Series Plot",
xlab = "Time",
ylab = "Rate"
)
Arguments
- data
A ts object to be plotted.
- time
A vector of the same length of data that specifies the time component of each element of data.
- title
Title of plot.
- xlab
X-axis label.
- ylab
Y-axis label.
Details
Fortifies, then plots a ts object.